<?php
/*
Plugin Name: ByDesign Replicated Subfolder to Subdomain Redirect
Plugin URI: http://www.bydesign.com
Description: Redirects all subfolder replicated site url's to subdomain style url's.
Version: 1.2.1
Author: ByDesign Technologies
Author URI: http://www.bydesign.com
Updated: 2023/02/20
*/


// add 404 handler for replicated sites
add_action('template_redirect', 'find_rep');

$options = get_option('bd_replicated_options');
$webfolder = $options['bd_replicated_webfolder'];

define('API_URL', 'https://api.securefreedom.com/'.$webfolder.'/webservice/replicatedsiteapi.asmx?WSDL');

/**
 * 404 Handler that retrieves information from the WS based on rep id found in URL
 */
function find_rep() {

	$url_parts = parse_url($_SERVER['REQUEST_URI']);
	$extension = strtolower(pathinfo($url_parts['path'], PATHINFO_EXTENSION));
	$useragent = $_SERVER["HTTP_USER_AGENT"];


	if (
		strpos($useragent, "facebookexternalhit/") !== false ||          
		strpos($useragent, "Facebot") !== false ||
		strpos($useragent, "Google") !== false ||
		strpos($useragent, "Redirect") !== false
	) {
		#ignore;
	} elseif (
		$extension === "js" ||
		$extension === "jpeg" ||
		$extension === "jpg"
	) { 
		#ignore; 
	} elseif (is_404() && !is_admin()) {

		$repId = '';

		$query_aux = substr($_SERVER['REQUEST_URI'], 1, strlen($_SERVER['REQUEST_URI']));
		//If the URL is "{RepDID}/about-me" or "{RepDID}/" . In this case remove the / and everything after that. Resulting string is the {RepDID}
		if (strpos($query_aux, '/')) {
			$repId = stristr($query_aux, '/', true);
		} else {
			//Url might be /{RepDID}. In this case use what is in $query_aux that is the {RepDID}

			$repId = $query_aux;
			if (strpos($repId, '?')) {
				$repId = strtok($repId,'?');
			}
		}

		$success = validate_rep($repId);

		if ($success) {

			//redirect to the page requested by the user in the URL
			$urlWithoutRepId = substr($_SERVER['REQUEST_URI'], strlen($repId) + 1,  strlen($_SERVER['REQUEST_URI']));

			$pos = strpos($urlWithoutRepId, '/');
			if ($pos === false) {
				$urlWithoutRepId = '/';
			}

			$baseUrl = str_ireplace("www.", "", $_SERVER['SERVER_NAME']);

			wp_redirect("https://" . $repId . "." . $baseUrl . $urlWithoutRepId , 302);
			exit;
		}

	}

}



/*
 * Gets the Rep info from the Webservice if it does not exist.
 */
function validate_rep($repId) {

	$success = false;

	try {
		$client = new SoapClient(
			API_URL,
			array (
				'soap_version'=>SOAP_1_1,
				'exceptions' => true,
				'trace' => 1,
				'cache_wsdl' => WSDL_CACHE_NONE //WSDL_CACHE_MEMORY,
			)
		);
	
		$options = get_option('bd_replicated_options');

		$params = array(
			'Credentials' => array('Username'=>$options['bd_replicated_user'],
								 'Password'=>$options['bd_replicated_password'],
								 'Token' => 'foo'),
			'Replicated'  => $repId,
			'UrlReferrer' => get_bloginfo('url')
		);

		$result = $client->GetRepInfo_v3($params);

		if (!$result->GetRepInfo_v3Result->Success == 1) {

			$errors = new WP_Error();
			$errors->add('replicated_error', 'Rep not found.');
			
		} else {

			$success = true;

		}

	}
	catch (Exception $e) {
		//print_r($e);
		$errors = new WP_Error();
		$errors->add('replicated_error', 'API not available.');
	}

	return $success;
}

?>
